An object of S3 class annualnoise with the following attributes:
auto.corrSample autocorrelation.
lm.fitlm object from regression of log power spectrum on log frequency.
intervalUpper and lower bounds of a 95% acceptance region when \(\rho=0\).
log.logMatrix with log frequency and log power spectrum.
reg.statsSlope and intercept of regression of log power spectrum on log frequency, where slope is the annual noise color (theta.a).
orderIndicates order of fitted AR model.
fit.arObject of class ar summarizing the fitted AR model.