compare.periods: Compare residual variability across time periods
Description
The function finds the seasonal signal in the first of two time periods within the data series. This signal is used to calculate residual flows in the first time period and "historical residuals", the residuals when the second period is compared to the signal in the first period.
The output of the function gives event information for all residual events greater than \(\sigma\) as calculated from the functions sigmaHighFlows and sigmaLowFlows.
# NOT RUN {# load datadata("sycamore")
# compare for periods from 1960 to 1979 and 1980 to 1999compare.periods(c("1960-01-01", "1979-12-31"),
c("1980-01-01", "1999-12-31"), sycamore)
# }