Learn R Programming

discharge (version 1.0.0)

etowah: Etowah River Data

Description

A data series from USGS station 02392000, Etowah River (Canton,GA).

Usage

data(etowah)

Arguments

Format

The data are supplied as a matrix with years in the first column and average daily discharge in the second column. The series contains 18282 observations starting Jan 1, 1960 and ending Dec 31, 2009.