An object of class list with items
n.droughtsNumber of independent events with negative residuals.
sigma.lfaEstimated sigma using the y-intercept.
sigma.lfbEstimated sigma using the slope (\(\sigma.lf\)).
drought.lineMatrix containing fitted, observed, and residual values from regression of log counts on bin midpoints.
onesigma.eventsmatrix containing information for all events below \(\sigma.lf\) (as calculated using the slope). Columns will contain the same data as the output from the independentEvents function.
twosigma.eventsmatrix containing information for all events below \(2\sigma.lf\). Columns will contain the same data as the output from the independentEvents function.